#
# Copyright (c) 2008-2017 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from onf_website.component.paragraph.skin.interfaces.frame import IUnborderedFrameParagraphRendererSettings, \
    IUnborderedLeftFrameParagraphRendererSettings, IUnborderedRightFrameParagraphRendererSettings
from pyams_content.component.paragraph.interfaces.frame import IFrameParagraph
from pyams_content.features.renderer.interfaces import IContentRenderer
from pyams_default_theme.component.paragraph.frame import BaseFrameParagraphRendererSettings, \
    DefaultFrameParagraphRenderer, FRAME_PARAGRAPH_RENDERER_SETTINGS_KEY, LEFT_FRAME_PARAGRAPH_RENDERER_SETTINGS_KEY, \
    LateralFrameParagraphRendererSettings, LeftFrameParagraphRenderer, RIGHT_FRAME_PARAGRAPH_RENDERER_SETTINGS_KEY, \
    RightFrameParagraphRenderer
from pyams_skin.layer import IPyAMSLayer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config, get_annotation_adapter
from pyams_utils.factory import factory_config

from onf_website import _


#
# Un-bordered framed text paragraph renderer settings
#

@factory_config(IUnborderedFrameParagraphRendererSettings)
class UnborderedFrameParagraphRendererSettings(BaseFrameParagraphRendererSettings):
    """Un-bordered framed paragraph renderer settings"""


@adapter_config(context=IFrameParagraph, provides=IUnborderedFrameParagraphRendererSettings)
def unbordered_frame_paragraph_renderer_settings_factory(context):
    """Framed paragraph default renderer settings factory"""
    return get_annotation_adapter(context, FRAME_PARAGRAPH_RENDERER_SETTINGS_KEY + '.unbordered',
                                  IUnborderedFrameParagraphRendererSettings)


@factory_config(IUnborderedLeftFrameParagraphRendererSettings)
class UnborderedLeftFrameParagraphRendererSettings(LateralFrameParagraphRendererSettings):
    """Un-bordered left framed paragraph lateral renderer settings"""


@adapter_config(context=IFrameParagraph, provides=IUnborderedLeftFrameParagraphRendererSettings)
def unbordered_left_lateral_frame_paragraph_renderer_settings_factory(context):
    """Left framed paragraph renderer settings factory"""
    return get_annotation_adapter(context, LEFT_FRAME_PARAGRAPH_RENDERER_SETTINGS_KEY + '.unbordered',
                                  IUnborderedLeftFrameParagraphRendererSettings)


@factory_config(IUnborderedRightFrameParagraphRendererSettings)
class UnborderedRightFrameParagraphRendererSettings(LateralFrameParagraphRendererSettings):
    """Un-bordered right framed paragraph lateral renderer settings"""


@adapter_config(context=IFrameParagraph, provides=IUnborderedRightFrameParagraphRendererSettings)
def unbordered_right_lateral_frame_paragraph_renderer_settings_factory(context):
    """Right framed paragraph lateral renderer settings factory"""
    return get_annotation_adapter(context, RIGHT_FRAME_PARAGRAPH_RENDERER_SETTINGS_KEY + '.unbordered',
                                  IUnborderedRightFrameParagraphRendererSettings)


#
# Framed text paragraph renderers
#

@adapter_config(name='default', context=(IFrameParagraph, IPyAMSLayer), provides=IContentRenderer)
@template_config(template='templates/frame-default.pt', layer=IPyAMSLayer)
class ONFDefaultFrameParagraphRenderer(DefaultFrameParagraphRenderer):
    """Framed text paragraph default renderer"""

    label = _("ONF: Default centered frame")
    weight = 1


@adapter_config(name='unbordered', context=(IFrameParagraph, IPyAMSLayer), provides=IContentRenderer)
@template_config(template='templates/frame-unbordered.pt', layer=IPyAMSLayer)
class ONFUnborderedFrameParagraphRenderer(DefaultFrameParagraphRenderer):
    """Framed text paragraph default renderer"""

    label = _("ONF: Un-bordered centered frame")
    weight = 2

    settings_interface = IUnborderedFrameParagraphRendererSettings


@adapter_config(name='left', context=(IFrameParagraph, IPyAMSLayer), provides=IContentRenderer)
@template_config(template='templates/frame-left.pt', layer=IPyAMSLayer)
class ONFLeftFrameParagraphRenderer(LeftFrameParagraphRenderer):
    """Left framed text paragraph renderer"""

    label = _("ONF: Small bordered frame on the left")
    weight = 3


@adapter_config(name='unbordered-left', context=(IFrameParagraph, IPyAMSLayer), provides=IContentRenderer)
@template_config(template='templates/frame-unbordered-left.pt', layer=IPyAMSLayer)
class ONFUnborderedLeftFrameParagraphRenderer(LeftFrameParagraphRenderer):
    """Left un-bordered framed paragraph renderer"""

    label = _("ONF: Un-bordered frame on the left")
    weight = 4

    settings_interface = IUnborderedLeftFrameParagraphRendererSettings


@adapter_config(name='right', context=(IFrameParagraph, IPyAMSLayer), provides=IContentRenderer)
@template_config(template='templates/frame-right.pt', layer=IPyAMSLayer)
class ONFRightFrameParagraphRenderer(RightFrameParagraphRenderer):
    """Right framed text paragraph renderer"""

    label = _("ONF: Small bordered frame on the right")
    weight = 5


@adapter_config(name='unbordered-right', context=(IFrameParagraph, IPyAMSLayer), provides=IContentRenderer)
@template_config(template='templates/frame-unbordered-right.pt', layer=IPyAMSLayer)
class ONFUnborderedRightFrameParagraphRenderer(RightFrameParagraphRenderer):
    """Right un-bordered framed paragraph renderer"""

    label = _("ONF: Un-bordered frame on the right")
    weight = 6

    settings_interface = IUnborderedRightFrameParagraphRendererSettings
